def create(values = None):
  # "name": {
  #   "text": ...
  #   "family": ...
  #   "given": ...
  #   "prefix": ...
  #   "suffix": ...
  # }
  record = {
    "patientId": None,
    "name": None,
    "managingOrganization": None,
    "sex": None,
    "race": None,
    "ethnicity": None,
    "dateOfBirth": None
  }
  if values!=None:
    record.update(values)
  return record


def create(values = None):
  record = {
    "genomeBuild": None,
    "coordinateSystem": None,
    "chrom": None,
    "gene": None,
    "refCN": None,
    "cn": None,
    "lowCI": None,
    "lowCIThreshold": None,
    "highCI": None,
    "highCIThreshold": None,
    "log2": None,
    "hotspot": None,
    "call": None,
    "location": None,

    "interpretation": None,
    "therapyRecommendation": None,
  }
  if values!=None:
    record.update(values)
  return record



def create(values = None):
  # "specimen": {
  #   "id": ...
  #   "type": {
  #     "coding": [
  #       "system",
  #       "code",
  #       "display",
  #     ],
  #     "text": ...
  #   }
  # }
  #
  #
  # "collection": {
  #   "type": {
  #     "coding": [
  #       "system",
  #       "code",
  #       "display",
  #     ],
  #     "text": ...
  #   }
  # }
  # "bodySite": {
  #   "type": {
  #     "coding": [
  #       "system",
  #       "code",
  #       "display",
  #     ],
  #     "text": ...
  #   }
  # }
  record = {
    "sampleId": None,
    "patientId": None,
    "tumorContent": None,
    "disease": None,
    "diseaseOntology": None,
    "detailedDisease": None,
    "detailedDiseaseOntology": None,
    "alternativeDiseaseSystems": None,
    "indication": None,
    "sourceType": None,
    "specimen": None,
    "receivedTime": None,
    "collector": None,
    "collectedTime": None,
    "age": None,
    "bodySite": None
  }
  if values!=None:
    record.update(values)
  return record


def create(values = None):
  record = {
    "sampleId": None,
    "analysisName": None,
    "pipelineName": None,
    "pipelineVersion": None,
    "analysisCenter": None,
    "analysisCenterSampleId":None,
    "panelName": None,
    "qcFailed": None,
    "calls": []
  }
  if values!=None:
    record.update(values)
  return record
